@@ -1,5 +1,5 @@
 from typing import Literal
-from text import text_element, TextType
+from .text import text_element, TextType
 
 
 def button_element(
